<?php
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.
require_once('PleskException.php');

class kavmng extends errHandler {

    function cmd($args)
    {
        $cmdstr = 'kavmng';
        $rv = util_exec($cmdstr, $args);

        if ( $rv === false) {
            global $plesk_errormsg;

            foreach ($args AS $arg) {
                $cmdstr .= ' ';
                $cmdstr .= $arg;
            }
            throw new PleskFatalException($cmdstr . ' failed: ' . $plesk_errormsg);
            return $rv;
        }
        return sizeof($rv) > 0 ? $rv : true;
    }

    function applyStatus(Db_Table_Row_ServiceNode $serviceNode, $status, $addr, $addr_id = null) {
        static $cmds = array(
            Mail_VirusFilter_UserController_Abstract::STATUS_NONE => array("remove"),
            Mail_VirusFilter_UserController_Abstract::STATUS_INCOMING => array("add", "incoming"),
            Mail_VirusFilter_UserController_Abstract::STATUS_OUTGOING => array("add", "outgoing"),
            Mail_VirusFilter_UserController_Abstract::STATUS_ANY => array("add", "both") );

        if ($status != Mail_VirusFilter_UserController_Abstract::STATUS_NONE) {
            $this->checkLicenseLimit($addr_id);
        }

        $args = array_merge(
            $cmds[$status],
            array(
                $addr,
            )
        );

        $serviceNode->agent()->execAndGetResponse('kavmng',  $args);
    }

    static function getAllDomains($dom_id, $domname) {
        $dom_id = (int)$dom_id;
        $rs = db_query("SELECT displayName FROM domain_aliases WHERE dom_id = {$dom_id} AND mail='true'");
        $rv = array($domname);
        while ($rec = mysql_fetch_object($rs)) {
            $rv[] = $rec->displayName;
        }

        return $rv;
    }

    static function getAllMails($dom_id) {
        $dom_id = (int)$dom_id;
        $rs = db_query("SELECT id, mail_name, virusfilter FROM mail WHERE dom_id = {$dom_id} AND virusfilter != 'none'");
        $rv = array();
        while ($rec = mysql_fetch_object($rs)) {
            $rv[] = array('id' => $rec->id, 'name' => $rec->mail_name, 'filter' => $rec->virusfilter);
        }
        $rs = db_query("SELECT mn.id, ma.alias, mn.virusfilter FROM mail_aliases ma JOIN mail mn ON (mn.id = ma.mn_id) WHERE mn.dom_id = {$dom_id} AND mn.virusfilter != 'none'");
        while ($rec = mysql_fetch_object($rs)) {
            $rv[] = array('id' => $rec->id, 'name' => $rec->alias, 'filter' => $rec->virusfilter);
        }

        return $rv;
    }

    static function get_kav_license()
    {
        return of_get_key_by_product("kav-unified") ? : of_get_key_by_product("kav-unix");
    }

    static function key_installed()
    {
        return file_exists("/opt/kav/sdk8l3/bin/kav.key")
           && self::get_kav_license();
    }

    private function _getLicenseLimit()
    {
        if (!self::key_installed()) {
            throw new PleskLicenseKeyException('The required Kaspersky additional key is not installed');
        }

        $kav_key = self::get_kav_license();
        $licenseLimit = getAdditionalKeyPropList($kav_key)['key_mailboxes'];
        if (is_array($licenseLimit) && SWKEY_UNLIMITED === $licenseLimit[0]) {
            return -1;
        }
        return intval($licenseLimit);
    }

    public function checkLicenseLimit($addr_id = null)
    {
        $licenseLimit = $this->_getLicenseLimit();
        if (-1 === $licenseLimit) {
            return;
        }

        $query = 'SELECT COUNT(`id`) FROM `mail` WHERE `virusfilter` != "' . Mail_VirusFilter_UserController_Abstract::STATUS_NONE . '"';
        if ($addr_id) {
            $query .= ' AND id != ' . (int)$addr_id;
        }
        list($filtered_mailnames_count) = db_fetch_row(db_query($query));

        if ($licenseLimit - intval($filtered_mailnames_count) <= 0) {
            throw new PleskLicenseLimitException('You have reached the limit on number of mailboxes defined by your Kaspersky license key (' . $licenseLimit . ')');
        }
    }
}