<?php
// Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.
require_once ('kavmng.php' );

class kavFilter implements Mail_VirusFilter_Interface
{
	public function getName()
	{
		return 'Kaspersky AntiVirus';
	}

	public function getUserController(User_Abstract $user)
	{
		static $cache = array();

		if ($user->getType() != Session::IS_MAIL_USER)
		return null;

		if (!isset($cache[$user->getId()])) {
			$cache[$user->getId()] = new kavVirusFilterUserController($user);
		}
		return $cache[$user->getId()];
	}


	public function applyStatus($status)
	{
		static $status_cmds = array(
			Mail_VirusFilter_Interface::STATUS_ON => "on",
			Mail_VirusFilter_Interface::STATUS_OFF => "off");

		$mng = new kavmng();
		$mng->cmd(array($status_cmds[$status]));
	}

	public function available()
	{
		return kavmng::key_installed();
	}
}

class kavVirusFilterUserController extends Mail_VirusFilter_UserController_Abstract {

	function getAllMails()
	{
		$user = $this->user;

		$domain = $user->getDomain();
		$dom_id = $domain->getId();

		$domainnames = kavmng::getAllDomains($dom_id, $domain->getDisplayName());
		
		$mailname = $user->getMailnameRow();
        $mailnames = array();
        $mailAliasesRowSet = Db_Table_Broker::get('Mailaliases')->findByField('mn_id', $mailname->id);
        foreach ($mailAliasesRowSet as $mailAliasRow) {
            $mailnames[] = $mailAliasRow->alias;
        }
		$mailnames[] = $mailname->getMailname();

		$rv = array();
		foreach ($domainnames as $dname) {
			foreach ($mailnames as $mname) {
				$rv[ $mname . '@' . $dname ] = $mailname->id;
			}
		}
		return $rv;
	}

	public function applyStatus($status) {
		$mng = new kavmng();
		$allmails = $this->getAllMails();

        /** @var Db_Table_Broker_ServiceNodes $serviceNodesBroker  */
        $serviceNodesBroker = Db_Table_Broker::get('ServiceNodes');
        $serviceNode = $serviceNodesBroker->getMailServiceNodeByDomainId($this->user->getDomain()->getId());

		foreach ($allmails as $maddr => $maddr_id) {
			$mng->applyStatus($serviceNode, $status, $maddr, $maddr_id);
		}
	}
}

return array ('kav' => new kavFilter());

?>
